==> cdi-tck-2.0.6-dist.zip: org/jboss/cdi/tck/tests/context/passivating/dependency/builtin/Inspector.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2014, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.cdi.tck.tests.context.passivating.dependency.builtin;

import java.io.Serializable;
import java.util.UUID;

import javax.annotation.PostConstruct;
import javax.enterprise.context.Dependent;
import javax.enterprise.inject.spi.InjectionPoint;
import javax.inject.Inject;

/**
 * @author Kirill Gaevskii
 *
 */
@Dependent
public class Inspector implements Serializable {

    private static final long serialVersionUID = 7238311288238399562L;
    
    private String id;
    
    @PostConstruct
    private void init() {
        id = UUID.randomUUID().toString();
    }
    
    @Inject
    InjectionPoint injectionPoint;
    
    public InjectionPoint getInjectionPoint() {
        return injectionPoint;
    }
    
    public String getId() {
        return id;
    }

}

==> cdi-tck-3.0.0-dist.zip: org/jboss/cdi/tck/tests/context/passivating/dependency/builtin/Inspector.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2014, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.cdi.tck.tests.context.passivating.dependency.builtin;

import java.io.Serializable;
import java.util.UUID;

import jakarta.annotation.PostConstruct;
import jakarta.enterprise.context.Dependent;
import jakarta.enterprise.inject.spi.InjectionPoint;
import jakarta.inject.Inject;

/**
 * @author Kirill Gaevskii
 *
 */
@Dependent
public class Inspector implements Serializable {

    private static final long serialVersionUID = 7238311288238399562L;
    
    private String id;
    
    @PostConstruct
    private void init() {
        id = UUID.randomUUID().toString();
    }
    
    @Inject
    InjectionPoint injectionPoint;
    
    public InjectionPoint getInjectionPoint() {
        return injectionPoint;
    }
    
    public String getId() {
        return id;
    }

}
